@@ -28,6 +28,9 @@ pub trait Vec3Ext {
 
     /// Natural logarithm of all three components.
     fn ln(self) -> Self;
+
+    /// The reflection of a incident vector and surface normal.
+    fn reflect(self, normal: Self) -> Self;
 }
 
 impl Vec3Ext for Vec3 {
@@ -68,6 +71,10 @@ impl Vec3Ext for Vec3 {
     fn ln(self) -> Self {
         vec3(self.x.ln(), self.y.ln(), self.z.ln())
     }
+
+    fn reflect(self, normal: Vec3) -> Self {
+        self - 2.0 * normal * self.dot(normal)
+    }
 }
 
 /// Coordinate system extension to [`Vec3`]
